<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-compagnon?lang_cible=br
// ** ne pas modifier le fichier **

return [

	// C
	'compagnon_description' => 'An ambrouger a ginnig sikour d’an implijerien
		da vare ar c’hentañ weladenn el lec’h prevez SPIP.',
	'compagnon_nom' => 'Ambrouger',
	'compagnon_slogan' => 'Ambrouger evit kregiñ gant SPIP',
];
